/* what we are */
#undef PACKAGE
#undef VERSION

/* debugging */
#undef NDEBUG

/* where to put data-subdirs */
#undef LOCALDATADIR

/* what compressor we can use */
#undef USE_MAIN_COMPRESSOR

/* For i18n */
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef ENABLE_NLS
#undef HAVE_GETTEXT
#undef HAVE_CATGETS
#undef LOCALEDIR

/* where to look for unicode data */
#undef UNICODEDATA
